==> nextcloud-app-deck-1%3a1.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/bg.js <==
OC.L10N.register(
    "deck",
    {
    "Personal" : "Лични",
    "Finished" : "Готово",
    "To review" : "За преглед",
    "Action needed" : "Необходимо е действие",
    "Later" : "По-късно",
    "copy" : "Копиране",
    "Done" : "Готово",
    "The file was uploaded" : "Файлът е качен",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Размерът на файла надвишава максималния размер определен от MAX_FILE_SIZE в HTML формата.",
    "The file was only partially uploaded" : "Файлът е качен частично",
    "No file was uploaded" : "Нито един файл не е качен",
    "Missing a temporary folder" : "Липсва временна папка",
    "Cancel" : "Отказ",
    "File already exists" : "Файлът вече съществува",
    "Do you want to overwrite it?" : "Искате ли да го презапишете?",
    "Filter by tag" : "Филтрирай по маркер",
    "Details" : "Подробности",
    "Sharing" : "Споделяне",
    "Tags" : "Етикети",
    "Undo" : "Отмяна",
    "Can edit" : "Може да редактира",
    "Can share" : "Може да споделя",
    "Delete" : "Изтриване",
    "Edit" : "Редакция",
    "Due date" : "Крайна дата",
    "Remove due date" : "Премахни крайната дата",
    "Description" : "Описание",
    "Attachments" : "Прикачени файлове",
    "Comments" : "Коментари",
    "Modified" : "Промяна",
    "Created" : "Създаден",
    "Upload attachment" : "Качване",
    "Save" : "Запазване",
    "Reply" : "Отговори",
    "Update" : "Обновяване",
    "(group)" : "(група)",
    "seconds ago" : "преди секунди",
    "Settings" : "Настройки",
    "Share" : "Сподели",
    "An error occurred" : "Възникна грешка"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3a1.1.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/bg.js <==
OC.L10N.register(
    "deck",
    {
    "Personal" : "Лични",
    "Finished" : "Готово",
    "To review" : "За преглед",
    "Action needed" : "Необходимо е действие",
    "Later" : "По-късно",
    "copy" : "Копиране",
    "Done" : "Готово",
    "The file was uploaded" : "Файлът е качен",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Размерът на файла надвишава максималния размер определен от MAX_FILE_SIZE в HTML формата.",
    "The file was only partially uploaded" : "Файлът е качен частично",
    "No file was uploaded" : "Нито един файл не е качен",
    "Missing a temporary folder" : "Липсва временна папка",
    "Cancel" : "Отказ",
    "File already exists" : "Файлът вече съществува",
    "Do you want to overwrite it?" : "Искате ли да го презапишете?",
    "Filter by tag" : "Филтрирай по маркер",
    "Details" : "Подробности",
    "Sharing" : "Споделяне",
    "Tags" : "Етикети",
    "Undo" : "Отмяна",
    "Can edit" : "Може да редактира",
    "Can share" : "Може да споделя",
    "Delete" : "Изтриване",
    "Edit" : "Редакция",
    "Title" : "Име",
    "Members" : "Членове",
    "Upload attachment" : "Качване",
    "Due date" : "Крайна дата",
    "Remove due date" : "Премахни крайната дата",
    "Description" : "Описание",
    "Attachments" : "Прикачени файлове",
    "Comments" : "Коментари",
    "Select Date" : "Изберете дата",
    "Modified" : "Промяна",
    "Created" : "Създаден",
    "Save" : "Запазване",
    "Reply" : "Отговори",
    "Update" : "Обновяване",
    "(group)" : "(група)",
    "seconds ago" : "преди секунди",
    "Shared with you" : "Споделени с вас",
    "An error occurred" : "Възникна грешка",
    "Today" : "Днес",
    "Tomorrow" : "Утре",
    "This week" : "Тази седмица"
},
"nplurals=2; plural=(n != 1);");
